aboutsummaryrefslogtreecommitdiffstats
path: root/include/sec.h
diff options
context:
space:
mode:
authorJoerie de Gram <j.de.gram@gmail.com>2011-08-17 15:57:47 +0200
committerJoerie de Gram <j.de.gram@gmail.com>2011-08-17 15:57:47 +0200
commitd3bd80a932e4f76b6cae280c78f118882f3b176d (patch)
treecad99877da53cad9fae5907fd43fe5a79e50ad37 /include/sec.h
parenta3c46bd32430db57b97a1498d3da9a2c01df22ad (diff)
downloadexternal_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.zip
external_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.tar.gz
external_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.tar.bz2
Rename library to libsamsung-ipc
Diffstat (limited to 'include/sec.h')
-rw-r--r--include/sec.h82
1 files changed, 41 insertions, 41 deletions
diff --git a/include/sec.h b/include/sec.h
index bd8629b..28db4f8 100644
--- a/include/sec.h
+++ b/include/sec.h
@@ -1,68 +1,68 @@
/**
* This file is part of libmsm-h1.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
* libmsm-h1 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* libmsm-h1 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with libmsm-h1. If not, see <http://www.gnu.org/licenses/>.
+ * along with libsamsung-ipc. If not, see <http://www.gnu.org/licenses/>.
*
*/
#ifndef __SEC_H__
#define __SEC_H__
-#define MSM_SEC_PIN_STATUS 0x0501
-#define MSM_SEC_PHONE_LOCK 0x0502
-#define MSM_SEC_CHANGE_LOCKING_PW 0x0503
-#define MSM_SEC_SIM_LANG 0x0504
-#define MSM_SEC_RSIM_ACCESS 0x0505
-#define MSM_SEC_GSIM_ACCESS 0x0506
-#define MSM_SEC_SIM_ICC_TYPE 0x0507
-#define MSM_SEC_LOCK_INFO 0x0508
-#define MSM_SEC_ISIM_AUTH 0x0509
+#define IPC_SEC_PIN_STATUS 0x0501
+#define IPC_SEC_PHONE_LOCK 0x0502
+#define IPC_SEC_CHANGE_LOCKING_PW 0x0503
+#define IPC_SEC_SIM_LANG 0x0504
+#define IPC_SEC_RSIM_ACCESS 0x0505
+#define IPC_SEC_GSIM_ACCESS 0x0506
+#define IPC_SEC_SIM_ICC_TYPE 0x0507
+#define IPC_SEC_LOCK_INFO 0x0508
+#define IPC_SEC_ISIM_AUTH 0x0509
-#define MSM_SEC_PIN_SIM_INITIALIZING 0x00
-#define MSM_SEC_PIN_SIM_SIM_LOCK_REQUIRED 0x01
-#define MSM_SEC_PIN_SIM_INSIDE_PF_ERROR 0x02
-#define MSM_SEC_PIN_SIM_LOCK_SC 0x03
-#define MSM_SEC_PIN_SIM_LOCK_FD 0x04
-#define MSM_SEC_PIN_SIM_LOCK_PN 0x05
-#define MSM_SEC_PIN_SIM_LOCK_PU 0x06
-#define MSM_SEC_PIN_SIM_LOCK_PP 0x07
-#define MSM_SEC_PIN_SIM_LOCK_PC 0x08
-#define MSM_SEC_PIN_SIM_CARD_NOT_PRESENT 0x80
-#define MSM_SEC_PIN_SIM_CARD_ERROR 0x81
-#define MSM_SEC_PIN_SIM_INIT_COMPLETE 0x82
-#define MSM_SEC_PIN_SIM_PB_INIT_COMPLETE 0x83
+#define IPC_SEC_PIN_SIM_INITIALIZING 0x00
+#define IPC_SEC_PIN_SIM_SIM_LOCK_REQUIRED 0x01
+#define IPC_SEC_PIN_SIM_INSIDE_PF_ERROR 0x02
+#define IPC_SEC_PIN_SIM_LOCK_SC 0x03
+#define IPC_SEC_PIN_SIM_LOCK_FD 0x04
+#define IPC_SEC_PIN_SIM_LOCK_PN 0x05
+#define IPC_SEC_PIN_SIM_LOCK_PU 0x06
+#define IPC_SEC_PIN_SIM_LOCK_PP 0x07
+#define IPC_SEC_PIN_SIM_LOCK_PC 0x08
+#define IPC_SEC_PIN_SIM_CARD_NOT_PRESENT 0x80
+#define IPC_SEC_PIN_SIM_CARD_ERROR 0x81
+#define IPC_SEC_PIN_SIM_INIT_COMPLETE 0x82
+#define IPC_SEC_PIN_SIM_PB_INIT_COMPLETE 0x83
/* Key types for the SIM card (SC) facility */
-#define MSM_SEC_PIN_SIM_LOCK_SC_PIN1_REQ 0x01
-#define MSM_SEC_PIN_SIM_LOCK_SC_PUK_REQ 0x02
-#define MSM_SEC_PIN_SIM_LOCK_SC_CARD_BLOCKED 0x05
+#define IPC_SEC_PIN_SIM_LOCK_SC_PIN1_REQ 0x01
+#define IPC_SEC_PIN_SIM_LOCK_SC_PUK_REQ 0x02
+#define IPC_SEC_PIN_SIM_LOCK_SC_CARD_BLOCKED 0x05
-#define MSM_SEC_PIN_TYPE_PIN1 0x03
-#define MSM_SEC_PIN_TYPE_PIN2 0x09
+#define IPC_SEC_PIN_TYPE_PIN1 0x03
+#define IPC_SEC_PIN_TYPE_PIN2 0x09
-#define MSM_SEC_SIM_CARD_TYPE_UNKNOWN 0x00
-#define MSM_SEC_SIM_CARD_TYPE_SIM 0x01
-#define MSM_SEC_SIM_CARD_TYPE_USIM 0x02
+#define IPC_SEC_SIM_CARD_TYPE_UNKNOWN 0x00
+#define IPC_SEC_SIM_CARD_TYPE_SIM 0x01
+#define IPC_SEC_SIM_CARD_TYPE_USIM 0x02
-struct msm_sec_pin_status_noti {
+struct ipc_sec_pin_status_noti {
unsigned char type;
unsigned char key;
} __attribute__((__packed__));
-struct msm_sec_pin_status_set {
+struct ipc_sec_pin_status_set {
unsigned char type;
unsigned char length1;
unsigned char length2;
@@ -70,30 +70,30 @@ struct msm_sec_pin_status_set {
unsigned char pin2[8];
} __attribute__((__packed__));
-struct msm_sec_phone_lock {
+struct ipc_sec_phone_lock {
unsigned char type;
unsigned char status;
} __attribute__((__packed__));
-struct msm_sec_rsim_access_request {
+struct ipc_sec_rsim_access_request {
unsigned char command;
unsigned short fileid;
unsigned char p1, p2, p3;
} __attribute__((__packed__));
-struct msm_sec_rsim_access_response {
+struct ipc_sec_rsim_access_response {
unsigned char sw1, sw2;
unsigned char len;
} __attribute__((__packed__));
-struct msm_sec_lock_info {
+struct ipc_sec_lock_info {
unsigned char num;
unsigned char type;
unsigned char key;
unsigned char attempts;
} __attribute__((__packed__));
-void msm_sec_rsim_access(unsigned char command, unsigned short file_id,
+void ipc_sec_rsim_access(unsigned char command, unsigned short file_id,
unsigned char p1, unsigned char p2, unsigned char p3,
unsigned char *rdata, unsigned int length, int request_id);
@@ -1,68 +1,68 @@
/**
- * This file is part of libmsm-h1.
+ * This file is part of libsamsung-ipc.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
@@ -1,68 +1,68 @@
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
- * libmsm-h1 is free software: you can redistribute it and/or modify
+ * libsamsung-ipc is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -1,68 +1,68 @@
* (at your option) any later version.
*
- * libmsm-h1 is distributed in the hope that it will be useful,
+ * libsamsung-ipc is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the